@@ -24,9 +24,7 @@ class DummyData(object):
         self.application_id = "nexmo-application-id"
         self.private_key = read_file("data/private_key.txt")
         self.public_key = read_file("data/public_key.txt")
-        self.user_agent = "vonage-python/{} python/{}".format(
-            vonage.__version__, platform.python_version()
-        )
+        self.user_agent = f"vonage-python/{vonage.__version__} python/{platform.python_version()}"
         self.host = "rest.nexmo.com"
         self.api_host = "api.nexmo.com"
 
@@ -50,7 +48,7 @@ def client(dummy_data):
 
 # Represents an instance of the Voice class for testing
 @pytest.fixture
-def voice(client, dummy_data):
+def voice(client):
     import vonage
 
     return vonage.Voice(client)
@@ -58,7 +56,7 @@ def voice(client, dummy_data):
 
 # Represents an instance of the Sms class for testing
 @pytest.fixture
-def sms(client, dummy_data):
+def sms(client):
     import vonage
 
     return vonage.Sms(client)
@@ -66,7 +64,55 @@ def sms(client, dummy_data):
 
 # Represents an instance of the Verify class for testing
 @pytest.fixture
-def verify(client, dummy_data):
+def verify(client):
     import vonage
 
     return vonage.Verify(client)
+
+@pytest.fixture
+def number_insight(client):
+    import vonage
+
+    return vonage.NumberInsight(client)
+
+@pytest.fixture
+def account(client):
+    import vonage
+
+    return vonage.Account(client)
+
+@pytest.fixture
+def numbers(client):
+    import vonage
+    
+    return vonage.Numbers(client)
+
+@pytest.fixture
+def ussd(client):
+    import vonage
+    
+    return vonage.Ussd(client)
+
+@pytest.fixture
+def short_codes(client):
+    import vonage
+    
+    return vonage.ShortCodes(client)
+
+@pytest.fixture
+def messages(client):
+    import vonage
+
+    return vonage.Messages(client)
+
+@pytest.fixture
+def redact(client):
+    import vonage
+
+    return vonage.Redact(client)
+
+@pytest.fixture
+def application_v2(client):
+    import vonage
+
+    return vonage.ApplicationV2(client)
\ No newline at end of file
